@@ -120,7 +120,11 @@ def retrieve_schedule_asset_instances(client: CogniteClient) -> List:
 
 def retrieve_air_schedules(client: CogniteClient) -> List[Schedule]:
     schedules = client.functions.schedules.list()
-    schedules = filter(lambda x: "air-functions" in x.function_external_id, schedules)
+    model_assets = retrieve_model_assets(client)
+    model_assets_external_ids = [i.external_id for i in model_assets]
+    for schedule in schedules:
+        schedule.model_ext_id = from_function_ext_id_to_model_name(schedule.function_external_id)
+    schedules = filter(lambda x: schedule.model_ext_id in model_assets_external_ids, schedules)
     schedules = [function_schedule_to_schedule(i) for i in schedules]
     return schedules
 
@@ -130,14 +134,22 @@ def retrieve_schedule_assets(client: CogniteClient) -> Iterator:
     model_assets = retrieve_model_assets(client)
     model_external_ids = [m.external_id for m in model_assets]
     schedule_assets = filter(
-        lambda a: a.parent_external_id in model_external_ids and "schedule" in a.name,
+        lambda a: a.parent_external_id in model_external_ids
+        and "schedule" in a.name
+        and a.metadata.get("deleted", "False") != "True",
         air_assets,
     )
     return schedule_assets
 
 
 def from_function_ext_id_to_model_name(function_external_id: str) -> str:
-    return function_external_id.split("/")[2].split(":")[0]
+    """Get the model name from function external id.
+    For non-AIR models just return an empty string.
+    """
+    try:
+        return function_external_id.split("/")[2].split(":")[0]
+    except IndexError:
+        return ""
 
 
 def function_schedule_to_schedule(function_schedule: FunctionSchedule):
