@@ -7,7 +7,7 @@ from tempfile import TemporaryDirectory
 from cognite.client import CogniteClient
 from cognite.experimental import CogniteClient as ExperimentalClient
 
-from cognite.airworkflow.constants import PROJECT_TO_API_KEYS
+from cognite.airworkflow.constants import PROJECTS_TO_API_KEYS
 from cognite.airworkflow.model.project import Project
 
 os.environ["COGNITE_MAX_RETRIES"] = "5"
@@ -66,8 +66,8 @@ def await_function_deployment(client: ExperimentalClient, function_name: str, ma
 
 def experimental_client(project: Project, api_key: str = "", base_url: str = None) -> ExperimentalClient:
     return ExperimentalClient(
-        api_key=api_key if api_key else PROJECT_TO_API_KEYS[project].get_client_api_key(),
+        api_key=api_key if api_key else PROJECTS_TO_API_KEYS[project].get_client_api_key(),
         client_name="AIR Functions Client",
         project=project.value,
-        base_url=base_url if base_url else PROJECT_TO_API_KEYS[project].base_url,
+        base_url=base_url if base_url else PROJECTS_TO_API_KEYS[project].base_url,
     )
